Module: Roda::RodaPlugins::Assets::RequestMethods
- Defined in:
- lib/roda/plugins/assets.rb
Instance Method Summary collapse
-
#assets ⇒ Object
Render the matching asset if this is a GET request for a supported asset.
Instance Method Details
#assets ⇒ Object
Render the matching asset if this is a GET request for a supported asset.
931 932 933 934 935 936 937 938 939 940 |
# File 'lib/roda/plugins/assets.rb', line 931 def assets if is_get? self.class.assets_matchers.each do |type, matcher| is matcher do |file| scope.render_asset(file, type) end end nil end end |