Method: Roda::RodaPlugins::Base::ClassMethods#call

Defined in:
lib/roda.rb

#call(env) ⇒ Object

Call the internal rack application with the given environment. This allows the class itself to be used as a rack application. However, for performance, it’s better to use #app to get direct access to the underlying rack app.



52
53
54
# File 'lib/roda.rb', line 52

def call(env)
  app.call(env)
end