Module: Roda::RodaPlugins::BearerToken

Defined in:
lib/roda/plugins/bearer_token.rb

Overview

The bearer_token plugin adds an r.bearer_token method for retrieving a bearer token from the Authorization HTTP header. Bearer tokens will in the authorization header will be recognized as long as they start with the case insensitive string “bearer ”.

Defined Under Namespace

Modules: RequestMethods

Constant Summary collapse

METHOD =

:nocov:

RUBY_VERSION >= "2.4" ? :match? : :match