Module: Roda::RodaPlugins::IPFromHeader::RequestMethods
- Defined in:
- lib/roda/plugins/ip_from_header.rb
Instance Method Summary collapse
-
#ip ⇒ Object
Return the IP address continained in the configured header, if present.
Instance Method Details
#ip ⇒ Object
Return the IP address continained in the configured header, if present. Fallback to the default behavior if not present.
26 27 28 |
# File 'lib/roda/plugins/ip_from_header.rb', line 26 def ip @env[roda_class.opts[:ip_from_header_env_key]] || super end |