Module: Roda::RodaPlugins::MatchHook
- Defined in:
- lib/roda/plugins/match_hook.rb
Overview
The match_hook plugin adds hooks that are called upon a successful match by any of the matchers. The hooks do not take any arguments. If you would like hooks that pass the arguments/matchers and values yielded to the route block, use the match_hook_args plugin.
plugin :match_hook
match_hook do
logger.debug("#{request.matched_path} matched. #{request.remaining_path} remaining.")
end
Defined Under Namespace
Modules: ClassMethods, InstanceMethods, RequestMethods
Class Method Summary collapse
Class Method Details
.configure(app) ⇒ Object
17 18 19 |
# File 'lib/roda/plugins/match_hook.rb', line 17 def self.configure(app) app.opts[:match_hooks] ||= [] end |