Module: Roda::RodaPlugins::Middleware::ClassMethods
- Defined in:
- lib/roda/plugins/middleware.rb
Instance Method Summary collapse
-
#new(app, *args, &block) ⇒ Object
Create a Forwarder instead of a new instance if a non-Hash is given.
Instance Method Details
#new(app, *args, &block) ⇒ Object
Create a Forwarder instead of a new instance if a non-Hash is given.
123 124 125 126 127 128 129 |
# File 'lib/roda/plugins/middleware.rb', line 123 def new(app, *args, &block) if app.is_a?(Hash) super else Forwarder.new(self, app, *args, &block) end end |