Module: Roda::RodaPlugins::MultiView::RequestMethods

Defined in:
lib/roda/plugins/multi_view.rb

Instance Method Summary collapse

Instance Method Details

#multi_view(arg) ⇒ Object

Pass the argument to get, and assume if the matchers match that there is one capture, and call view with that capture.



77
78
79
80
81
# File 'lib/roda/plugins/multi_view.rb', line 77

def multi_view(arg)
  get(arg) do |page|
    scope.view(page)
  end
end