Module: Roda::RodaPlugins::NamedRoutes::RequestMethods
- Defined in:
- lib/roda/plugins/named_routes.rb
Instance Method Summary collapse
-
#route(name, namespace = nil) ⇒ Object
Dispatch to the named route with the given name.
Instance Method Details
#route(name, namespace = nil) ⇒ Object
Dispatch to the named route with the given name.
160 161 162 |
# File 'lib/roda/plugins/named_routes.rb', line 160 def route(name, namespace=nil) scope.send(roda_class.named_route(name, namespace), self) end |