Module: Roda::RodaPlugins::ParamsCapturingRestore

Defined in:
lib/roda/plugins/params_capturing_restore.rb

Overview

The params_capturing_restore plugin allows the params_capturing plugin to work with the use of r.pass (pass plugin) or break (break plugin) inside a block that uses param capturing, restoring the previous state of the params.

This is not done by the params_capturing plugin as it requires significant extra work for every param capturing block, and most users of the params_capturing plugin are not using the pass or break plugins.

Defined Under Namespace

Modules: RequestMethods

Constant Summary collapse

REQUEST_INSTANCE_VARIABLES =
[:@_params_captures_restore].freeze

Class Method Summary collapse

Class Method Details

.load_dependencies(app) ⇒ Object



20
21
22
# File 'lib/roda/plugins/params_capturing_restore.rb', line 20

def self.load_dependencies(app)
  app.plugin :params_capturing
end