Module: Roda::RodaPlugins::R

Defined in:
lib/roda/plugins/r.rb

Overview

The r plugin adds an r instance method that will return the request. This allows you to use common Roda idioms such as r.halt and r.redirect even when r isn't a local variable in scope. Example:

plugin :r

def foo
r.redirect "/bar"
end

route do |r|
r.get "foo" do
  foo
end
r.get "bar" do
  "bar"
end
end

Defined Under Namespace

Modules: InstanceMethods