Exception: Roda::RodaPlugins::TypecastParams::Error

Inherits:
Roda::RodaError
  • Object
show all
Defined in:
lib/roda/plugins/typecast_params.rb

Overview

Exception class for errors that are due to the submitted parameters not matching what is expected. Should probably be treated as a 4xx error.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#all_errorsObject



329
330
331
# File 'lib/roda/plugins/typecast_params.rb', line 329

def all_errors
  @all_errors ||= [self]
end

#keysObject

The keys used to access the parameter that caused the error. This is an array that can be splatted to dig to get the value of the parameter causing the error.



318
319
320
# File 'lib/roda/plugins/typecast_params.rb', line 318

def keys
  @keys
end

#reasonObject

The reason behind this error. If this error was caused by a conversion method, this will be the the conversion method symbol. If this error was caused because a value was missing, then it will be :missing. If this error was caused because a value was not the correct type, then it will be :invalid_type.



337
338
339
# File 'lib/roda/plugins/typecast_params.rb', line 337

def reason
  @reason
end

Class Method Details

.create(keys, reason, e) ⇒ Object

Set the keys in the given exception. If the exception is not already an instance of the class, create a new instance to wrap it.



301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/roda/plugins/typecast_params.rb', line 301

def self.create(keys, reason, e)
  if e.is_a?(self)
    e.keys ||= keys
    e.reason ||= reason
    e
  else
    backtrace = e.backtrace
    e = new("#{e.class}: #{e.message}")
    e.keys = keys
    e.reason = reason
    e.set_backtrace(backtrace) if backtrace
    e
  end
end

Instance Method Details

#param_nameObject

The likely parameter name where the contents were not expected. This is designed for cases where the parameter was submitted with the typical application/x-www-form-urlencoded or multipart/form-data content types, and assumes the typical rack parsing of these content types into parameters. # If the parameters were submitted via JSON, #keys should be used directly.

Example:

# keys: ['page']
param_name => 'page'

# keys: ['artist', 'name']
param_name => 'artist[name]'

# keys: ['album', 'artist', 'name']
param_name => 'album[artist][name]'


356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/roda/plugins/typecast_params.rb', line 356

def param_name
  if keys.length > 1
    first, *rest = keys
    v = first.dup
    rest.each do |param|
      v << "["
      v << param unless param.is_a?(Integer)
      v << "]"
    end
    v
  else
    keys.first
  end
end

#param_namesObject

An array of all parameter names for parameters where the context were not expected. If Params#convert! was not used, this will be an array containing #param_name. If Params#convert! was used and multiple exceptions were captured inside the convert! block, this will contain the parameter names related to all captured exceptions.



376
377
378
# File 'lib/roda/plugins/typecast_params.rb', line 376

def param_names
  all_errors.map(&:param_name)
end