Module: Roda::RodaPlugins::TypecastParams::InstanceMethods

Defined in:
lib/roda/plugins/typecast_params.rb

Instance Method Summary collapse

Instance Method Details

#typecast_body_paramsObject

Return and cache the instance of the TypecastParams class wrapping access to parameters in the request's body. Type conversion methods will be called on the result of this method.



1177
1178
1179
# File 'lib/roda/plugins/typecast_params.rb', line 1177

def typecast_body_params
  @_typecast_body_params ||= self.class::TypecastParams.new(@_request.POST)
end

#typecast_paramsObject

Return and cache the instance of the TypecastParams class wrapping access to the request's params (merging query string params and body params). Type conversion methods will be called on the result of this method.



1163
1164
1165
# File 'lib/roda/plugins/typecast_params.rb', line 1163

def typecast_params
  @_typecast_params ||= self.class::TypecastParams.new(@_request.params)
end

#typecast_query_paramsObject

Return and cache the instance of the TypecastParams class wrapping access to parameters in the request's query string. Type conversion methods will be called on the result of this method.



1170
1171
1172
# File 'lib/roda/plugins/typecast_params.rb', line 1170

def typecast_query_params
  @_typecast_query_params ||= self.class::TypecastParams.new(@_request.GET)
end