Module: Roda::RodaPlugins::HashPublic::RequestMethods
- Defined in:
- lib/roda/plugins/hash_public.rb
Instance Method Summary collapse
-
#hash_public ⇒ Object
Serve files from the public directory if the file exists, it includes the hash_public prefix segment followed by a string segment for the content hash, and this is a GET request.
Instance Method Details
#hash_public ⇒ Object
Serve files from the public directory if the file exists, it includes the hash_public prefix segment followed by a string segment for the content hash, and this is a GET request.
113 114 115 116 117 118 119 |
# File 'lib/roda/plugins/hash_public.rb', line 113 def hash_public if is_get? on roda_class.opts[:hash_public_prefix], String do |_| public end end end |