Module: Roda::RodaPlugins::Mailer::RequestMethods
- Defined in:
- lib/roda/plugins/mailer.rb
Instance Method Summary collapse
-
#mail(*args) ⇒ Object
Similar to routing tree methods such as
getandpost, this matches only if the request method is MAIL (only set when using the Roda classmailorsendmailmethods) and the rest of the arguments match the request.
Instance Method Details
#mail(*args) ⇒ Object
Similar to routing tree methods such as get and post, this matches
only if the request method is MAIL (only set when using the Roda class
mail or sendmail methods) and the rest of the arguments match
the request. This yields any of the captures to the block, as well as
any arguments passed to the mail or sendmail Roda class methods.
177 178 179 180 181 182 183 184 |
# File 'lib/roda/plugins/mailer.rb', line 177 def mail(*args) if @env["REQUEST_METHOD"] == "MAIL" # RODA4: Make terminal match the default send(roda_class.opts[:mailer][:terminal] ? :_verb : :if_match, args) do |*vs| yield(*(vs + @env['roda.mail_args'])) end end end |