Module: Roda::RodaPlugins::MatchHook::InstanceMethods
- Defined in:
- lib/roda/plugins/match_hook.rb
Instance Method Summary collapse
-
#_match_hook ⇒ Object
Default empty method if no match hooks are defined.
Instance Method Details
#_match_hook ⇒ Object
Default empty method if no match hooks are defined.
44 45 |
# File 'lib/roda/plugins/match_hook.rb', line 44 def _match_hook end |